# Generated by Django 2.2.28 on 2022-05-13 08:25

import django.contrib.postgres.indexes
import m3_gar.models.indexes

from django.db import migrations
from django.contrib.postgres.operations import TrigramExtension


class Migration(migrations.Migration):

    dependencies = [
        ('m3_gar', '0012_auto_20220415_1452'),
    ]

    operations = [
        TrigramExtension(),
        migrations.RemoveIndex(
            model_name='admhierarchy',
            name='m3_gar_admh_name_wi_5f5f5a_gin',
        ),
        migrations.RemoveIndex(
            model_name='munhierarchy',
            name='m3_gar_munh_name_wi_380974_gin',
        ),
        migrations.AddIndex(
            model_name='addrobj',
            index=django.contrib.postgres.indexes.BTreeIndex(fields=['level'], name='m3_gar_addr_level_5ff8c6_btree'),
        ),
        migrations.AddIndex(
            model_name='admhierarchy',
            index=m3_gar.models.indexes.UpperGinIndex(fastupdate=True, fields=['name_with_parents'], name='adm_name_with_parents_gin', opclasses=['gin_trgm_ops']),
        ),
        migrations.AddIndex(
            model_name='munhierarchy',
            index=m3_gar.models.indexes.UpperGinIndex(fastupdate=True, fields=['name_with_parents'], name='mun_name_with_parents_gin', opclasses=['gin_trgm_ops']),
        ),
    ]
