# Generated by Django 3.2.6 on 2022-02-17 06:39

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('m3_gar', '0008_auto_20220217_0556'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Status',
        ),
    ]
